@@ -200,28 +200,14 @@ class dyn_obj:
         self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
         self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list)
 
-    def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
-        """
-        Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
-        :param str staticity: a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
-        :param np.ndarray int_x: a numpy array of the x position over time
-        :param np.ndarray int_y: a numpy array of the y position over time
-        :param np.ndarray int_z: a numpy array of the z position over time
-        
-        """
-
-
+    def apply_streamline(self, staticity, int_x, int_y, int_z, frames, thickness):
         name = self.name+'_streamline'
-        """:type: `str`, the Blender object name of the streamline"""
-        frames = self.frames
-        """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
 
-        
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
-        int_coords[:, 0] = int_x*self.scale
-        int_coords[:, 1] = int_y*self.scale
-        int_coords[:, 2] = int_z*self.scale
+        int_coords[:, 0] = int_x
+        int_coords[:, 1] = int_y
+        int_coords[:, 2] = int_z
 
         int_curve = bpy.data.curves.new(name, type='CURVE')
         int_curve.dimensions = '3D'
@@ -239,62 +225,15 @@ class dyn_obj:
 
         # attach to scene and validate context
         bpy.context.collection.objects.link(int_curveOB)
-        
+
         int_curveOB.data.bevel_depth = thickness
-        int_curveOB.data.use_fill_caps = True
-
-        int_curveOB.data.bevel_factor_start = 0
-
-        curve_to_mesh(int_curveOB)
-        self.streamline = bpy.data.objects[self.name+'_streamline']
 
         if staticity == 'dynamic':
-            int_size = len(int_x)
-            int_coords = np.zeros((int_size, 3))
-            int_coords[:, 0] = np.flip(int_x*self.scale)
-            int_coords[:, 1] = np.flip(int_y*self.scale)
-            int_coords[:, 2] = np.flip(int_z*self.scale)
+            for i in range(len(frames)):
+                cur_frame = frames[i]
 
-            self.streamline.shape_key_add(from_mix=False)
-
-            for i in range(len(self.frames)):
-                cur_frame = self.frames[i]
-                cur_zeros = np.arange(0, len(self.frames)-i)
-
-                int_curve = bpy.data.curves.new(name, type='CURVE')
-                
-                int_curve.dimensions = '3D'
-                int_curve.resolution_u = 2
-
-                # map coords to spline
-                int_line = int_curve.splines.new('NURBS')
-                int_line.points.add(len(int_coords))
-                for i, coord in enumerate(int_coords):
-                    x,y,z = coord
-                    int_line.points[i].co = (x, y, z, 1)
-
-                # create Object
-                int_curveOB = bpy.data.objects.new(name, int_curve)
-
-                # attach to scene and validate context
-                bpy.context.collection.objects.link(int_curveOB)
-                
-                int_curveOB.data.bevel_depth = thickness
-                int_curveOB.data.use_fill_caps = True
-
-                int_curveOB.data.bevel_factor_start = 0
-                int_curveOB.name = 'tmp'
-
-                curve_to_mesh(int_curveOB)
-
-                tmp_curve_mesh = bpy.data.objects['tmp']
-                
-                bpy.context.view_layer.objects.active = tmp_curve_mesh
-                self.streamline.select_set(state=True)
-
-                bpy.ops.object.join_shapes()
-
-                bpy.data.objects.remove(tmp_curve_mesh)
+                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]) * cur_frame
+                bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
             
 
 class dyn_vec:
